Eco-Connect @ Ecorithm
======================

.. image:: https://circleci.com/gh/ecorithm/eco_connect.svg?style=svg
    :target: https://circleci.com/gh/ecorithm/eco_connect

.. image:: https://codecov.io/gh/ecorithm/eco_connect/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/ecorithm/eco_connect

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black

A wrapper for connecting to Ecorithm’s API Platform through Python


Documentation
-------------

Available at https://eco-connect.readthedocs.io/en/latest/index.html
